==========
User Guide
==========

This user guide covers essential features of libpysal, mostly in the form of interactive Jupyter notebooks. Reading this guide, you will learn:

- work with built-in example spatial data sets
- how to use spatial weights
- how to use spatial graphs

Notebooks cover just a small selection of functions as an illustration of
principles. For a full overview of momepy capabilities, head to the `API <../api.rst>`_.


.. toctree::
   :maxdepth: 1

   Datasets <data/examples>
   Weights <weights/intro>
   Graphs  <graph/intro>
